<?php
/**
 * Theme functions and definitions
 *
 * @package lifestyle_blogging
 */

if ( ! function_exists( 'lifestyle_blogging_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function lifestyle_blogging_enqueue_styles() {
		wp_enqueue_style( 'ovation-blog-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'lifestyle-blogging-style', get_stylesheet_directory_uri() . '/style.css', array( 'ovation-blog-style-parent' ), '1.0.0' );
        // Theme Customize CSS.
        require get_parent_theme_file_path( 'inc/extra_customization.php' );
        wp_add_inline_style( 'lifestyle-blogging-style',$ovation_blog_custom_style );
	}
endif;
add_action( 'wp_enqueue_scripts', 'lifestyle_blogging_enqueue_styles', 99 );

function lifestyle_blogging_customize_register() {
    global $wp_customize;
    $wp_customize->remove_section( 'ovation_blog_pro' );
    $wp_customize->remove_section( 'ovation_blog_post' );

    $wp_customize->remove_setting( 'ovation_blog_top_category_text' );
    $wp_customize->remove_control( 'ovation_blog_top_category_text' );

    $wp_customize->remove_setting( 'ovation_blog_top_category_heading' );
    $wp_customize->remove_control( 'ovation_blog_top_category_heading' );
}
add_action( 'customize_register', 'lifestyle_blogging_customize_register', 11 );

function lifestyle_blogging_customize( $wp_customize ) {

    wp_enqueue_style('customizercustom_css', esc_url( get_stylesheet_directory_uri() ). '/assets/css/customizer.css');

    $wp_customize->add_section('lifestyle_blogging_pro', array(
        'title'    => __('UPGRADE BLOGGING PREMIUM', 'lifestyle-blogging'),
        'priority' => 1,
    ));

    $wp_customize->add_setting('lifestyle_blogging_pro', array(
        'default'           => null,
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control(new Lifestyle_Blogging_Pro_Control($wp_customize, 'lifestyle_blogging_pro', array(
        'label'    => __('BLOGGING PREMIUM', 'lifestyle-blogging'),
        'section'  => 'lifestyle_blogging_pro',
        'settings' => 'lifestyle_blogging_pro',
        'priority' => 1,
    )));
}
add_action( 'customize_register', 'lifestyle_blogging_customize' );

function lifestyle_blogging_header_style() {
    if ( get_header_image() ) :
    $custom_css = "
        .wrap_figure{
            background-image:url('".esc_url(get_header_image())."');
            background-position: center top;
        }";
        wp_add_inline_style( 'ovation-blog-style', $custom_css );
    endif;
}
add_action( 'wp_enqueue_scripts', 'lifestyle_blogging_header_style' );

function lifestyle_blogging_setup() {
    add_theme_support( "align-wide" );
    add_theme_support( "wp-block-styles" );
    add_theme_support( 'responsive-embeds' );
    add_theme_support( 'woocommerce' );
    add_theme_support( 'automatic-feed-links' );
    add_theme_support( 'post-thumbnails' );
    add_theme_support( 'title-tag' );
    add_theme_support('custom-background',array(
        'default-color' => 'ffffff',
    ));
    add_image_size( 'lifestyle-blogging-featured-image', 2000, 1200, true );
    add_image_size( 'lifestyle-blogging-thumbnail-avatar', 100, 100, true );

    $GLOBALS['content_width'] = 525;

    add_theme_support( 'html5', array(
        'comment-form',
        'comment-list',
        'gallery',
        'caption',
    ) );

    // Add theme support for Custom Logo.
    add_theme_support( 'custom-logo', array(
        'width'       => 250,
        'height'      => 250,
        'flex-width'  => true,
    ) );

    /*
     * This theme styles the visual editor to resemble the theme style,
     * specifically font, colors, and column width.
     */
    add_editor_style( array( 'assets/css/editor-style.css') );

}
add_action( 'after_setup_theme', 'lifestyle_blogging_setup' );

function lifestyle_blogging_widgets_init() {
    register_sidebar( array(
        'name'          => __( 'Sidebar', 'lifestyle-blogging' ),
        'id'            => 'sidebar-1',
        'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'lifestyle-blogging' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
        'after_title'   => '</h3></div>',
    ) );

    register_sidebar( array(
        'name'          => __( 'Page Sidebar', 'lifestyle-blogging' ),
        'id'            => 'sidebar-2',
        'description'   => __( 'Add widgets here to appear in your pages and posts', 'lifestyle-blogging' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
        'after_title'   => '</h3></div>',
    ) );

    register_sidebar( array(
        'name'          => __( 'Footer 1', 'lifestyle-blogging' ),
        'id'            => 'footer-1',
        'description'   => __( 'Add widgets here to appear in your footer.', 'lifestyle-blogging' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ) );

    register_sidebar( array(
        'name'          => __( 'Footer 2', 'lifestyle-blogging' ),
        'id'            => 'footer-2',
        'description'   => __( 'Add widgets here to appear in your footer.', 'lifestyle-blogging' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ) );

    register_sidebar( array(
        'name'          => __( 'Footer 3', 'lifestyle-blogging' ),
        'id'            => 'footer-3',
        'description'   => __( 'Add widgets here to appear in your footer.', 'lifestyle-blogging' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ) );

    register_sidebar( array(
        'name'          => __( 'Footer 4', 'lifestyle-blogging' ),
        'id'            => 'footer-4',
        'description'   => __( 'Add widgets here to appear in your footer.', 'lifestyle-blogging' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ) );
}
add_action( 'widgets_init', 'lifestyle_blogging_widgets_init' );

function lifestyle_blogging_enqueue_comments_reply() {
    if( get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
}
add_action( 'comment_form_before', 'lifestyle_blogging_enqueue_comments_reply' );

define('LIFESTYLE_BLOGGING_PRO_LINK',__('https://www.ovationthemes.com/wordpress/lifestyle-wordpress-theme/','lifestyle-blogging'));

/* Pro control */
if (class_exists('WP_Customize_Control') && !class_exists('Lifestyle_Blogging_Pro_Control')):
    class Lifestyle_Blogging_Pro_Control extends WP_Customize_Control{

    public function render_content(){?>
        <label style="overflow: hidden; zoom: 1;">
            <div class="col-md upsell-btn">
                <a href="<?php echo esc_url( LIFESTYLE_BLOGGING_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE BLOGGING PREMIUM','lifestyle-blogging');?> </a>
            </div>
            <div class="col-md">
                <img class="lifestyle_blogging_img_responsive " src="<?php echo esc_url( get_stylesheet_directory_uri() ); ?>/screenshot.png">
            </div>
            <div class="col-md">
                <h3 style="margin-top:10px; margin-left: 20px; text-decoration:underline; color:#333;"><?php esc_html_e('BLOGGING PREMIUM - Features', 'lifestyle-blogging'); ?></h3>
                <ul style="padding-top:10px">
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Responsive Design', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Boxed or fullwidth layout', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Shortcode Support', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Demo Importer', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Section Reordering', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Contact Page Template', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Multiple Blog Layouts', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Unlimited Color Options', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Designed with HTML5 and CSS3', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Customizable Design & Code', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Cross Browser Support', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Detailed Documentation Included', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Stylish Custom Widgets', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Patterns Background', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('WPML Compatible (Translation Ready)', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Woo-commerce Compatible', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Full Support', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('10+ Sections', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Live Customizer', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('AMP Ready', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Clean Code', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('SEO Friendly', 'lifestyle-blogging');?> </li>
                    <li class="upsell-lifestyle_blogging"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Supper Fast', 'lifestyle-blogging');?> </li>
                </ul>
            </div>
            <div class="col-md upsell-btn upsell-btn-bottom">
                <a href="<?php echo esc_url( LIFESTYLE_BLOGGING_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE BLOGGING PREMIUM','lifestyle-blogging');?> </a>
            </div>
        </label>
    <?php } }
endif;

if ( ! defined( 'OVATION_BLOG_SUPPORT' ) ) {
	define('OVATION_BLOG_SUPPORT',__('https://wordpress.org/support/theme/lifestyle-blogging','lifestyle-blogging'));
}
if ( ! defined( 'OVATION_BLOG_REVIEW' ) ) {
	define('OVATION_BLOG_REVIEW',__('https://wordpress.org/support/theme/lifestyle-blogging/reviews/#new-post','lifestyle-blogging'));
}
if ( ! defined( 'OVATION_BLOG_LIVE_DEMO' ) ) {
define('OVATION_BLOG_LIVE_DEMO',__('https://www.ovationthemes.com/demos/lifestyle-blogging/','lifestyle-blogging'));
}
if ( ! defined( 'OVATION_BLOG_BUY_PRO' ) ) {
define('OVATION_BLOG_BUY_PRO',__('https://www.ovationthemes.com/wordpress/lifestyle-wordpress-theme/','lifestyle-blogging'));
}
if ( ! defined( 'OVATION_BLOG_PRO_DOC' ) ) {
define('OVATION_BLOG_PRO_DOC',__('https://www.ovationthemes.com/docs/ot-lifestyle-blogging-pro-doc','lifestyle-blogging'));
}
if ( ! defined( 'OVATION_BLOG_PRO_THEME_NAME' ) ) {
define('OVATION_BLOG_PRO_THEME_NAME',__('Blogging Premium Theme','lifestyle-blogging'));
}
